==> fluent-api-generator-tests-2.0-sources.jar: fluent/api/generator/setters/ConsumerFixture.java <==
/*
 * BSD 2-Clause License
 *
 * Copyright (c) 2018, Ondrej Fischer
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *  Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package fluent.api.generator.setters;

public interface ConsumerFixture {

    void accept(
            @fluent.api.simple.FluentBuilder(factoryMethod = "pojo")
            @fluent.api.full.FluentBuilder(packageName = "fluent.api.generator.setters.full")
            PojoFixture pojoFixture
    );

    void accept(
            @fluent.api.simple.FluentBuilder(packageName = "fluent.api.generator.setters.simple")
            @fluent.api.full.FluentBuilder(factoryMethod = "stringPojo")
            GenericPojoFixture<String> genericPojoFixture
    );

    <T> void acceptGeneric(
            @fluent.api.simple.FluentBuilder(methodName = "create")
            @fluent.api.full.FluentBuilder(factoryMethod = "genericPojo", className = "TPojoBuilder")
            GenericPojoFixture<T> genericPojoFixture
    );
}

==> fluent-api-generator-tests-2.11-sources.jar: fluent/api/generator/setters/ConsumerFixture.java <==
/*
 * BSD 2-Clause License
 *
 * Copyright (c) 2018, Ondrej Fischer
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *  Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package fluent.api.generator.setters;

import fluent.api.FluentBuilder;
import fluent.api.FluentBuilderApi;

public interface ConsumerFixture {

    void accept(
            @FluentBuilder(factoryMethod = "pojo")
            @FluentBuilderApi(packageName = "fluent.api.generator.builder.full")
            PojoFixture pojoFixture
    );

    void accept(
            @FluentBuilder(packageName = "fluent.api.generator.builder.simple")
            @FluentBuilderApi(factoryMethod = "stringPojo")
            GenericPojoFixture<String> genericPojoFixture
    );

    <T> void acceptGeneric(
            @FluentBuilder(methodName = "create")
            @FluentBuilderApi(factoryMethod = "genericPojo", className = "TPojoBuilder")
            GenericPojoFixture<T> genericPojoFixture
    );
}
